var structopenvdb_1_1v12__0_1_1tools_1_1Sampler_3_010_00_01false_01_4 =
[
    [ "consistent", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#afd3da75b32679d899a56532f92469c8f", null ],
    [ "mipmap", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#a6c9ddbbbd600c052cade13207665aa39", null ],
    [ "name", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#a80926f21b03253a1045be08235e9d6ea", null ],
    [ "order", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#a4440d8900b99dab3c079c8b53775952f", null ],
    [ "radius", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#a4836a8d316f4fbaaf3064e0b1acd10ec", null ],
    [ "sample", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#af016e16ec50405c877a06287d54e7c3e", null ],
    [ "sample", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#ac6dc80e2a1753b4c79771e7d4ed37940", null ],
    [ "staggered", "structopenvdb_1_1v12__0_1_1tools_1_1Sampler.html#a0050bc9dc3e95de2ca035e98149763ed", null ]
];